@@ -1,5 +1,5 @@
 # $File: //depot/cpanplus/dist/lib/CPANPLUS/Internals/Make.pm $
-# $Revision: #13 $ $Change: 8399 $ $DateTime: 2003/10/13 09:02:19 $
+# $Revision: #15 $ $Change: 9265 $ $DateTime: 2003/12/11 20:21:43 $
 
 #######################################################
 ###             CPANPLUS/Internals/Make.pm          ###
@@ -478,23 +478,17 @@ warn "SHOULD NOT GET HERE" if $flag;
                 MAKE_TEST: {
                 unless ($skiptest) {
 
-                    if( defined $self->status->make_test ) {
+                    if( defined $data->status->make_test ) {
                         
-                        if( $self->status->make_test && !$force ) {
+                        if( $data->status->make_test && !$force ) {
                             $err->inform(
                                 msg     => loc(q[Already tested this module - not running '%1' again unless you force],
                                                 'make test' ),
-                                quiet   => $verbose
+                                quiet   => !$verbose
                             );
                             last MAKE_TEST;                                     
                         }
                          
-                    } else {
-                        $err->trap(
-                                error   => loc(q['%1' failed before this session, no point in retrying], 'make test'),
-                                quiet   => !$verbose 
-                        );
-                        last MAKE_TEST;          
                     }
 
 
